INTEGRITY Dokumentace

Zobrazení rulesetů

Tato stránka obsahuje příklady následujících operací API:

Zobrazení dostupných rulesetů

Můžete zobrazit seznam dostupných sad pravidel pro zónu nebo účet.

Seznam koncových bodů API najdete v Výpis a zobrazení sad pravidel.

Příklad: Zobrazení dostupných sad pravidel na úrovni zóny

Odpověď na Požadavek GET při získání seznamu sad pravidel na úrovni zóny bude zahrnovat následující sady pravidel:

Požadovaná oprávnění API tokenu

Alespoň jeden z následujících oprávnění tokenu je povinné:
Seznam sad pravidel zóny
curl "https://api.cloudflare.com/client/v4/zones/$ZONE_ID/rulesets" \
	--request GET \
	--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"
{
	"result": [
		{
			"id": "<ZONE_PHASE_RULESET_ID>",
			"name": "Zone-level Ruleset 1",
			"description": "Ruleset for http_request_firewall_managed phase at the zone level",
			"kind": "zone",
			"version": "2",
			"last_updated": "2021-03-12T14:11:59.754817Z",
			"phase": "http_request_firewall_managed"
		},
		{
			"id": "<CLOUDFLARE_MANAGED_RULESET_ID>",
			"name": "Cloudflare Managed Ruleset",
			"description": "Created by the Cloudflare security team, this ruleset is designed to provide fast and effective protection for all your applications. It is frequently updated to cover new vulnerabilities and reduce false positives",
			"kind": "managed",
			"version": "2",
			"last_updated": "2021-03-18T14:42:40.972022Z",
			"phase": "http_request_firewall_managed"
		},
		{
			"id": "<CLOUDFLARE_OWASP_CORE_RULESET_ID>",
			"name": "Cloudflare OWASP Core Ruleset",
			"description": "Cloudflare's implementation of the Open Web Application Security Project (OWASP) ModSecurity Core Rule Set. We routinely monitor for updates from OWASP based on the latest version available from the official code repository",
			"kind": "managed",
			"version": "3",
			"last_updated": "2021-03-18T14:42:42.993211Z",
			"phase": "http_request_firewall_managed"
		}
	],
	"success": true,
	"errors": [],
	"messages": []
}

Příklad: Zobrazení dostupných sad pravidel na úrovni účtu

Odpověď na Požadavek GET při získání seznamu sad pravidel na úrovni účtu bude zahrnovat následující sady pravidel:

Požadovaná oprávnění API tokenu

Alespoň jeden z následujících oprávnění tokenu je povinné:
Seznam sad pravidel na úrovni účtu
curl "https://api.cloudflare.com/client/v4/accounts/$ACCOUNT_ID/rulesets" \
	--request GET \
	--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"
{
	"result": [
		{
			"id": "<CUSTOM_RULESET_ID>",
			"name": "Custom Ruleset 1",
			"description": "My custom ruleset",
			"kind": "custom",
			"version": "10",
			"last_updated": "2020-11-23T11:36:24.192361Z",
			"phase": "http_request_firewall_custom"
		},
		{
			"id": "<ACCOUNT_PHASE_RULESET_ID>",
			"name": "Account-level ruleset for http_request_firewall_managed phase",
			"description": "Account-level ruleset for executing one or more Managed Rulesets",
			"kind": "root",
			"version": "2",
			"last_updated": "2021-03-12T14:06:41.323932Z",
			"phase": "http_request_firewall_managed"
		},
		{
			"id": "<CLOUDFLARE_MANAGED_RULESET_ID>",
			"name": "Cloudflare Managed Ruleset",
			"description": "Created by the Cloudflare security team, this ruleset is designed to provide fast and effective protection for all your applications. It is frequently updated to cover new vulnerabilities and reduce false positives",
			"kind": "managed",
			"version": "5",
			"last_updated": "2021-03-18T14:42:40.972022Z",
			"phase": "http_request_firewall_managed"
		},
		{
			"id": "<CLOUDFLARE_OWASP_CORE_RULESET_ID>",
			"name": "Cloudflare OWASP Core Ruleset",
			"description": "Cloudflare's implementation of the Open Web Application Security Project (OWASP) ModSecurity Core Rule Set. We routinely monitor for updates from OWASP based on the latest version available from the official code repository",
			"kind": "managed",
			"version": "3",
			"last_updated": "2021-03-18T14:42:42.993211Z",
			"phase": "http_request_firewall_managed"
		}
	],
	"success": true,
	"errors": [],
	"messages": []
}

Získání vstupní sady pravidel

Můžete získat definici vstupní sada pravidel daného fáze na úrovni zóny nebo účtu.

Pokud vstupní sada pravidel existuje, API vrátí 200 OK stavový kód HTTP spolu s definicí sady pravidel.

Pokud vstupní sada pravidel neexistuje, API vrátí 404 Not Found stavový kód HTTP.

Příklad: Získání vstupní sady pravidel na úrovni zóny

Následující Požadavek GET získá definici vstupní sady pravidel pro http_request_firewall_managed fázi na úrovni zóny. V tomto případě vstupní sada pravidel existuje a obsahuje jedno pravidlo.

Požadovaná oprávnění API tokenu

Alespoň jeden z následujících oprávnění tokenu je povinné:
Získání vstupní sady pravidel zóny
curl "https://api.cloudflare.com/client/v4/zones/$ZONE_ID/rulesets/phases/http_request_firewall_managed/entrypoint" \
	--request GET \
	--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"
{
	"result": {
		"id": "<RULESET_ID>",
		"name": "Zone-level phase entry point ruleset",
		"description": "This ruleset executes a managed ruleset.",
		"kind": "zone",
		"version": "2",
		"rules": [
			{
				"id": "<RULE_ID>",
				"version": "1",
				"action": "execute",
				"expression": "true",
				"action_parameters": {
					"id": "<MANAGED_RULESET_ID>"
				},
				"last_updated": "2021-03-17T15:42:37.917815Z"
			}
		],
		"last_updated": "2021-03-17T15:42:37.917815Z",
		"phase": "http_request_firewall_managed"
	},
	"success": true,
	"errors": [],
	"messages": []
}

Příklad: Získání vstupní sady pravidel na úrovni účtu

Následující Požadavek GET získá definici vstupní sady pravidel pro http_request_firewall_managed fáze na úrovni účtu.

Požadovaná oprávnění API tokenu

Alespoň jeden z následujících oprávnění tokenu je povinné:
Získání vstupní sady pravidel účtu
curl "https://api.cloudflare.com/client/v4/accounts/$ACCOUNT_ID/rulesets/phases/http_request_firewall_managed/entrypoint" \
	--request GET \
	--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"

Zobrazení pravidel obsažených v rulesetu

Můžete zobrazit všechny verze vstupních sad pravidel fáze (na úrovni účtu i zóny) a vlastních sad pravidel, u spravovaných sad pravidel však lze zobrazit pouze nejnovější verzi.

Příklad: Zobrazení pravidel ve vstupní sadě pravidel fáze na úrovni zóny

Následující Požadavek GET uvádí seznam pravidel ve verzi 2 http_request_firewall_managed vstupní sadu pravidel fáze na úrovni zóny.

Požadovaná oprávnění API tokenu

Alespoň jeden z následujících oprávnění tokenu je povinné:
Získání verze vstupní sady pravidel zóny
curl "https://api.cloudflare.com/client/v4/zones/$ZONE_ID/rulesets/phases/http_request_firewall_managed/entrypoint/versions/2" \
	--request GET \
	--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"
{
	"result": {
		"id": "<RULESET_ID>",
		"name": "Zone-level phase entry point ruleset",
		"description": "This ruleset executes a managed ruleset.",
		"kind": "zone",
		"version": "2",
		"rules": [
			{
				"id": "<RULE_ID>",
				"version": "1",
				"action": "execute",
				"expression": "true",
				"action_parameters": {
					"id": "<MANAGED_RULESET_ID>"
				},
				"last_updated": "2021-03-17T15:42:37.917815Z"
			}
		],
		"last_updated": "2021-03-17T15:42:37.917815Z",
		"phase": "http_request_firewall_managed"
	},
	"success": true,
	"errors": [],
	"messages": []
}

Příklad: Zobrazení pravidel ve spravované sadě pravidel

Následující Požadavek GET uvádí seznam pravidel ve verzi 2 spravované sady pravidel (nejnovější verze dané sady pravidel).

Každé pravidlo ve spravované sadě pravidel může mít přiřazené značky nebo kategorie, uvedené v categories .

Požadovaná oprávnění API tokenu

Alespoň jeden z následujících oprávnění tokenu je povinné:
Získání verze sady pravidel účtu
curl "https://api.cloudflare.com/client/v4/accounts/$ACCOUNT_ID/rulesets/$MANAGED_RULESET_ID/versions/2" \
	--request GET \
	--header "Authorization: Bearer $CLOUDFLARE_API_TOKEN"
{
	"result": {
		"id": "<MANAGED_RULESET_ID>",
		"name": "Cloudflare Managed Ruleset",
		"description": "Created by the Cloudflare security team, this ruleset is designed to provide fast and effective protection for all your applications. It is frequently updated to cover new vulnerabilities and reduce false positives",
		"kind": "managed",
		"version": "2",
		"rules": [
			{
				"id": "<RULE_1_ID>",
				"version": "1",
				"action": "log",
				"categories": [
					"cve-2014-5265",
					"cve-2014-5266",
					"cve-2014-5267",
					"dos",
					"drupal",
					"wordpress"
				],
				"description": "Drupal, Wordpress - DoS - XMLRPC - CVE:CVE-2014-5265, CVE:CVE-2014-5266, CVE:CVE-2014-5267",
				"last_updated": "2021-03-18T14:42:40.972022Z",
				"ref": "<RULE_1_REF>",
				"enabled": true
			},
			{
				"id": "<RULE_2_ID>",
				"version": "1",
				"action": "block",
				"categories": ["broken-access-control", "cve-2018-12895", "wordpress"],
				"description": "Wordpress - Broken Access Control - CVE:CVE-2018-12895",
				"last_updated": "2021-03-18T14:42:40.972022Z",
				"ref": "<RULE_2_REF>",
				"enabled": true
			}
			// (...)
		],
		"last_updated": "2021-03-18T14:42:40.972022Z",
		"phase": "http_request_firewall_managed"
	},
	"success": true,
	"errors": [],
	"messages": []
}

Další informace o dostupných metodách API pro zobrazení sad pravidel najdete v Výpis a zobrazení sad pravidel.